#include <stdio.h>
#include <fcntl.h>
#include <sys/stat.h>
#include <sys/types.h>

#define ULAW_SILENCE 0xff
#define MS20_BYTES  160

unsigned char silence[MS20_BYTES];

void pad_file(char *);

main(int argc, char **argv)
{
     int i;
     int nfiles;

     if (argc < 2) {
         fprintf(stderr,"Usage: %s <file name> ...\n",argv[0]);
         exit(1);
     }

     nfiles = argc - 1;
     for (i = 0; i < nfiles; i++) {
         pad_file(argv[i+1]);
     }

     exit(0);
}

void
pad_file(char *fname)
{
     int fd;
     int i;
     struct stat sbuf;
     int filesize;
     int remainder;
     int nwrite;

     fd = open(fname,O_WRONLY|O_APPEND);
     if (fd < 0) {
         fprintf(stderr,"Could not open %s for writing.\n",fname);
         return;
     }

     if (fstat(fd,&sbuf) != 0) {
         fprintf(stderr,"Could not stat file %s.\n",fname);
         return;
     }

     filesize = (int) sbuf.st_size;
     remainder = filesize % MS20_BYTES;
     if (remainder == 0) {
         close(fd);
         return;
     }

     nwrite = MS20_BYTES - remainder;
     for (i = 0; i < nwrite; i++)
         silence[i] = (unsigned char)ULAW_SILENCE;

     if (write(fd,(void *)silence,nwrite) != nwrite) {
         fprintf(stderr,"Write Failure on file %s\n",fname);
         return;
     }

     close(fd);
     return;
}
